!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!
! dissipation.f90	Subroutine to calculate dissipation terms in PV equation.
!			Subroutine calculates:
!						tend = dissipation (psi_in, q_in).
!			Dissipation consists of following options:
!			(i)   Ekman layers at upper and lower boundaries.
!			(ii)  Ekman layers at internal interfaces.
!			(iii) 2nd order PV hyperdiffusion.
!
!			Called by PROGRAM qgam.
! 
! twnh 7Jan01 & pdw 2Jul02
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

SUBROUTINE dissipation(psi_in, q_in, tend)

! load global variables
USE dyn_vars
USE grid_params
USE phys_params

IMPLICIT NONE

! declaration of local variables
REAL (KIND=wp), DIMENSION(N_rad, N_azim, N_layer), INTENT(IN)		:: psi_in, q_in		! input fields
REAL (KIND=wp), DIMENSION(N_rad, N_azim, N_layer), INTENT(INOUT)	:: tend			! tendency in q field
REAL (KIND=wp), DIMENSION(N_rad, N_azim, N_layer)			:: work1, work2		! temporary variables

WRITE(*,*) ' dissipation...'

! get Laplacian of (streamfunction - relaxation streamfunction)
work2 = psi_in - psi_relax
CALL laplacian(work2,work1)

! (i) Ekman layers at upper and lower boundaries
tend(:,:,N_layer) = tend(:,:,N_layer) - spindown_rate(N_layer)*work1(:,:,N_layer)
tend(:,:,      1) = tend(:,:,      1) - spindown_rate(      1)*work1(:,:,      1)

! (ii) Ekman layers at internal interfaces (currently for 2 layers only)
IF (internal_ekman == 1 .AND. N_layer == 2) THEN
	tend(:,:,1) = tend(:,:,1) - spindown_rate(1)*chi(2)*(work1(:,:,1)-work1(:,:,2))
	tend(:,:,2) = tend(:,:,2) - spindown_rate(2)*chi(1)*(work1(:,:,2)-work1(:,:,1))
ENDIF

! (iii) 2nd order PV hyperdiffusion
CALL laplacian(q_in, work1)
tend = tend + new_hyper*work1

END SUBROUTINE dissipation
