!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!
! dtheta.f90	Azimuthal derivative operator for use in calculating the forcing term.
!		Subroutine calculates:
!					out =  dtheta (in).
!
!		Called by SUBROUTINE forcing.
! 
! pdw 3Jan02
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

SUBROUTINE dtheta(in, out)

! load global variables
USE grid_params

IMPLICIT NONE

! local variables
REAL (KIND=wp), DIMENSION(N_rad, N_azim, N_layer), INTENT(IN)	:: in			! input field (could be psi or q)
REAL (KIND=wp), DIMENSION(N_rad, N_azim, N_layer), INTENT(OUT)	:: out			! d/dtheta (in)
INTEGER								:: j, jp, jm		! index 

WRITE(*,*) '  azimuthal derivative...'

! reset out array
out = 0.0_wp

DO j = 1, N_azim									! loop over azimuthal direction
	jp = j+1
	jm = j-1
		IF (j == 1) THEN							! azimuthal periodicity
			jm = N_azim
		ELSEIF (j == N_azim) THEN
			jp = 1
		ENDIF
		out(:,j,:) = in(:,jp,:) - in(:,jm,:)
END DO
out = out/(2.0_wp*delta_theta)

END SUBROUTINE dtheta
