!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!
! save_fields.f90	Dump state to disk.  Every dump_period the current step is saved.
!			Every pickup_dump_period the current and previous steps are saved.
!			Should change i/o to portable standard (eg. netcdf)...
!
!			Called by PROGRAM qgam.
! 
! twnh 15Aug01
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

SUBROUTINE save_fields

! load global variables
USE grid_params
USE dyn_vars

IMPLICIT NONE

! declaration of local variables
INTEGER ::  ii, jj, kk						! indices
CHARACTER (LEN=30) :: fullname
CHARACTER (LEN=10) :: ext

! decide between no dump, regular dump, or pickup dump at this time step

! regular dump of state at current step only
IF (MODULO(step, dump_period) == 0) THEN

	! build filename
	WRITE(ext,'(I10.10)') step

	! dump q field
	WRITE(fullname,'(A,A)') 'QGPV.',ext
	WRITE(*,*) ' save_fields: Dumping QGPV state at step: ',step,' to file: ',fullname
	OPEN(3, FILE=fullname, STATUS='unknown', FORM='UNFORMATTED')
	WRITE(3) (((REAL(q(ii,jj,kk,this_step), KIND=sp), ii=1,N_rad), jj=1,N_azim), kk=1,N_layer)
	CLOSE(3)

	! dump psi field
	WRITE(fullname,'(A,A)') 'PSI_.',ext
	WRITE(*,*) ' save_fields: Dumping streamfunction state at step: ',step,' to file: ',fullname
	OPEN(3, FILE=fullname, STATUS='unknown', FORM='UNFORMATTED')
	WRITE(3) (((REAL(psi(ii,jj,kk,this_step), KIND=sp), ii=1,N_rad), jj=1,N_azim), kk=1,N_layer)
	CLOSE(3)

END IF 

! pickup dump of state at current step and next step
IF (MODULO(step,pickup_dump_period) == 0) THEN

	! build filename
	WRITE(ext,'(I10.10)') step

	! dump q field
	WRITE(fullname,'(A,A,A)') 'QGPV.',ext,'.pu'
	WRITE(*,*) ' save_fields: Pickup dump of QGPV state at steps: ',step,', ',step+1,' to file: ',fullname
	OPEN(3, FILE=fullname, STATUS='unknown', FORM='UNFORMATTED')
	WRITE(3) (((q(ii,jj,kk,this_step), ii=1,N_rad), jj=1,N_azim), kk=1,N_layer)
	WRITE(3) (((q(ii,jj,kk,next_step), ii=1,N_rad), jj=1,N_azim), kk=1,N_layer)
	CLOSE(3)

	! dump psi field
	WRITE(fullname,'(A,A,A)') 'PSI_.',ext,'.pu'
	WRITE(*,*) ' save_fields: Pickup dump of streamfunction state at steps: ',step,', ',step+1,' to file: ',fullname
	OPEN(3, FILE=fullname, STATUS='unknown', FORM='UNFORMATTED')
	WRITE(3) (((psi(ii,jj,kk,this_step), ii=1,N_rad), jj=1,N_azim), kk=1,N_layer)
	WRITE(3) (((psi(ii,jj,kk,next_step), ii=1,N_rad), jj=1,N_azim), kk=1,N_layer)
	CLOSE(3)

END IF 

END SUBROUTINE save_fields
