%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% gradient_imp.m	Improved version of the Matlab built-in gradient function. 
%			
%			Built-in version uses centred two-point differences
%			everywhere except at the matrix edges, where uncentred two-point
%			differences are used.  This gives a biased result, and
%			produces a spurious signal in contour plots at theta=0.
%
%			This version exploits azimuthal periodicity, so that
%			centred two-point differences are used at the azimuthal
%			edges, eliminating the spurious signal.
%
%			[FX,FY] = GRADIENT_IMP(F,HX,HY)
%
% pdw 12th March 2003
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [fx, fy] = gradient_imp(f, hx, hy)

len = size(f, 2) ;

[fx_filteredx3, fy_filteredx3] = gradient([f,f,f], hx, hy) ;

fx = fx_filteredx3(:, len+1:2*len) ;
fy = fy_filteredx3(:, len+1:2*len) ;

return
